/************************************************************************//**
 *
 * @file	pport_m20_m21_m22_m23_m24_m25_reg.h
 *
 * @brief	Definition of the I/O Ports(PPORT) Register for S1C17M20/21/22/23/24/25.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 01 Sep. 2016    1.00
 *				- First revision.
 *
 ******************************************************************************/

#ifndef PPORT_REG_H__
#define PPORT_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// P0 Port Data Register
typedef union P0DAT_REG_TAG {
    unsigned short  reg;
    struct P0DAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P00IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P00IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P01IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P01IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P02IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P02IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P03IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P03IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P04IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P04IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P05IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P05IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P06IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P06IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P07IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P07IN       : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P00OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P00OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P01OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P01OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P02OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P02OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P03OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P03OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P04OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P04OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P05OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P05OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P06OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P06OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P07OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P07OUT      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0DAT_REG;

/// P0 Port Enable Register
typedef union P0IOEN_REG_TAG {
    unsigned short  reg;
    struct P0IOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .P00OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P00OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P01OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P01OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P02OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P02OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P03OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P03OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P04OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P04OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P05OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P05OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P06OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P06OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P07OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P07OEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P00IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P00IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P01IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P01IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P02IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P02IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P03IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P03IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P04IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P04IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P05IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P05IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P06IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P06IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P07IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P07IEN      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0IOEN_REG;

/// P0 Port Pull-up/down Control Register
typedef union P0RCTL_REG_TAG {
    unsigned short  reg;
    struct P0RCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P00REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P00REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P01REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P01REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P02REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P02REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P03REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P03REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P04REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P04REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P05REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P05REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P06REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P06REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P07REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P07REN      : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P00PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P00PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P01PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P01PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P02PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P02PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P03PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P03PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P04PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P04PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P05PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P05PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P06PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P06PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P07PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P07PDPU     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0RCTL_REG;

/// P0 Port Interrupt Flag Register
typedef union P0INTF_REG_TAG {
    unsigned short  reg;
    struct P0INTF_REG_BIT_TAG {
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P00IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P00IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P01IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P01IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P02IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P02IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P03IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P03IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P04IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P04IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P05IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P05IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P06IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P06IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P07IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P07IF       : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P0INTF_REG;

/// P0 Port Interrupt Control Register
typedef union P0INTCTL_REG_TAG {
    unsigned short  reg;
    struct P0INTCTL_REG_BIT_TAG {
        /**
         * This bit enable port input interrupt.
         * .P00IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P00IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P01IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P01IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P02IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P02IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P03IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P03IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P04IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P04IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P05IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P05IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P06IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P06IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P07IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P07IE       : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P00EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P00EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P01EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P01EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P02EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P02EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P03EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P03EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P04EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P04EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P05EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P05EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P06EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P06EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P07EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P07EDGE     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0INTCTL_REG;

/// P0 Port Chattering Filter Enable Register
typedef union P0CHATEN_REG_TAG {
    unsigned short  reg;
    struct P0CHATEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the chattering filter function.
         * .P00CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P00CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P01CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P01CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P02CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P02CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P03CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P03CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P04CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P04CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P05CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P05CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P06CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P06CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P07CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P07CHATEN   : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P0CHATEN_REG;

/// P0 Port Mode Select Register
typedef union P0MODSEL_REG_TAG {
    unsigned short  reg;
    struct P0MODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P00SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P00SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P01SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P01SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P02SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P02SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P03SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P03SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P04SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P04SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P05SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P05SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P06SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P06SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P07SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P07SEL      : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P0MODSEL_REG;

/// P0 Port Function Select Register
typedef union P0FNCSEL_REG_TAG {
    unsigned short  reg;
    struct P0FNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P00MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P00MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P01MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P01MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P02MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P02MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P03MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P03MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P04MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P04MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P05MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P05MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P06MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P06MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P07MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P07MUX      : 2;
    } bit;
    unsigned char   byte_reg[2];
} P0FNCSEL_REG;

/// P1 Port Data Register
typedef union P1DAT_REG_TAG {
    unsigned short  reg;
    struct P1DAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P10IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P10IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P11IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P11IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P12IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P12IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P13IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P13IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P14IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P14IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P15IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P15IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P16IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P16IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P17IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P17IN       : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P10OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P10OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P11OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P11OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P12OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P12OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P13OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P13OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P14OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P14OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P15OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P15OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P16OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P16OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P17OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P17OUT      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P1DAT_REG;

/// P1 Port Enable Register
typedef union P1IOEN_REG_TAG {
    unsigned short  reg;
    struct P1IOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .P10OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P10OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P11OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P11OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P12OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P12OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P13OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P13OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P14OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P14OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P15OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P15OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P16OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P16OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P17OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P17OEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P10IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P10IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P11IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P11IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P12IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P12IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P13IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P13IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P14IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P14IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P15IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P15IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P16IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P16IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P17IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P17IEN      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P1IOEN_REG;

/// P1 Port Pull-up/down Control Register
typedef union P1RCTL_REG_TAG {
    unsigned short  reg;
    struct P1RCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P10REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P10REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P11REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P11REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P12REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P12REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P13REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P13REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P14REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P14REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P15REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P15REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P16REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P16REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P17REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P17REN      : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P10PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P10PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P11PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P11PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P12PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P12PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P13PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P13PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P14PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P14PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P15PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P15PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P16PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P16PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P17PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P17PDPU     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P1RCTL_REG;

/// P1 Port Interrupt Flag Register
typedef union P1INTF_REG_TAG {
    unsigned short  reg;
    struct P1INTF_REG_BIT_TAG {
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P10IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P10IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P11IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P11IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P12IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P12IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P13IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P13IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P14IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P14IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P15IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P15IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P16IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P16IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P17IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P17IF       : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1INTF_REG;

/// P1 Port Interrupt Control Register
typedef union P1INTCTL_REG_TAG {
    unsigned short  reg;
    struct P1INTCTL_REG_BIT_TAG {
        /**
         * This bit enable port input interrupt.
         * .P10IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P10IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P11IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P11IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P12IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P12IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P13IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P13IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P14IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P14IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P15IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P15IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P16IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P16IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P17IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P17IE       : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P10EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P10EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P11EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P11EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P12EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P12EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P13EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P13EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P14EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P14EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P15EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P15EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P16EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P16EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P17EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P17EDGE     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P1INTCTL_REG;

/// P1 Port Chattering Filter Enable Register
typedef union P1CHATEN_REG_TAG {
    unsigned short  reg;
    struct P1CHATEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the chattering filter function.
         * .P10CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P10CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P11CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P11CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P12CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P12CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P13CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P13CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P14CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P14CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P15CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P15CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P16CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P16CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P17CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P17CHATEN   : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1CHATEN_REG;

/// P1 Port Mode Select Register
typedef union P1MODSEL_REG_TAG {
    unsigned short  reg;
    struct P1MODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P10SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P10SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P11SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P11SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P12SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P12SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P13SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P13SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P14SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P14SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P15SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P15SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P16SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P16SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P17SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P17SEL      : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1MODSEL_REG;

/// P1 Port Function Select Register
typedef union P1FNCSEL_REG_TAG {
    unsigned short  reg;
    struct P1FNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P10MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P10MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P11MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P11MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P12MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P12MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P13MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P13MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P14MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P14MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P15MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P15MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P16MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P16MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P17MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P17MUX      : 2;
    } bit;
    unsigned char   byte_reg[2];
} P1FNCSEL_REG;

/// P2 Port Data Register
typedef union P2DAT_REG_TAG {
    unsigned short  reg;
    struct P2DAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P20IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P20IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P21IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P21IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P22IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P22IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P23IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P23IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P24IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P24IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P25IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P25IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P26IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P26IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P27IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P27IN       : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P20OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P20OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P21OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P21OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P22OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P22OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P23OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P23OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P24OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P24OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P25OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P25OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P26OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P26OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P27OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P27OUT      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P2DAT_REG;

/// P2 Port Enable Register
typedef union P2IOEN_REG_TAG {
    unsigned short  reg;
    struct P2IOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .P20OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P20OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P21OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P21OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P22OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P22OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P23OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P23OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P24OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P24OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P25OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P25OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P26OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P26OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P27OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P27OEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P20IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P20IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P21IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P21IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P22IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P22IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P23IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P23IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P24IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P24IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P25IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P25IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P26IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P26IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P27IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P27IEN      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P2IOEN_REG;

/// P2 Port Pull-up/down Control Register
typedef union P2RCTL_REG_TAG {
    unsigned short  reg;
    struct P2RCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P20REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P20REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P21REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P21REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P22REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P22REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P23REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P23REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P24REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P24REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P25REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P25REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P26REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P26REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P27REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P27REN      : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P20PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P20PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P21PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P21PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P22PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P22PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P23PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P23PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P24PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P24PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P25PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P25PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P26PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P26PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P27PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P27PDPU     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P2RCTL_REG;

/// P2 Port Interrupt Flag Register
typedef union P2INTF_REG_TAG {
    unsigned short  reg;
    struct P2INTF_REG_BIT_TAG {
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P20IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P20IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P21IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P21IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P22IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P22IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P23IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P23IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P24IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P24IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P25IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P25IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P26IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P26IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P27IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P27IF       : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P2INTF_REG;

/// P2 Port Interrupt Control Register
typedef union P2INTCTL_REG_TAG {
    unsigned short  reg;
    struct P2INTCTL_REG_BIT_TAG {
        /**
         * This bit enable port input interrupt.
         * .P20IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P20IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P21IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P21IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P22IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P22IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P23IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P23IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P24IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P24IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P25IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P25IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P26IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P26IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P27IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P27IE       : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P20EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P20EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P21EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P21EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P22EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P22EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P23EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P23EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P24EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P24EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P25EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P25EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P26EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P26EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P27EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P27EDGE     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P2INTCTL_REG;

/// P2 Port Chattering Filter Enable Register
typedef union P2CHATEN_REG_TAG {
    unsigned short  reg;
    struct P2CHATEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the chattering filter function.
         * .P20CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P20CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P21CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P21CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P22CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P22CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P23CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P23CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P24CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P24CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P25CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P25CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P26CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P26CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P27CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P27CHATEN   : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P2CHATEN_REG;

/// P2 Port Mode Select Register
typedef union P2MODSEL_REG_TAG {
    unsigned short  reg;
    struct P2MODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P20SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P20SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P21SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P21SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P22SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P22SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P23SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P23SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P24SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P24SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P25SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P25SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P26SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P26SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P27SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P27SEL      : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P2MODSEL_REG;

/// P2 Port Function Select Register
typedef union P2FNCSEL_REG_TAG {
    unsigned short  reg;
    struct P2FNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P20MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P20MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P21MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P21MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P22MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P22MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P23MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P23MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P24MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P24MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P25MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P25MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P26MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P26MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P27MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P2nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P27MUX      : 2;
    } bit;
    unsigned char   byte_reg[2];
} P2FNCSEL_REG;

/// P3 Port Data Register
typedef union P3DAT_REG_TAG {
    unsigned short  reg;
    struct P3DAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P30IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P30IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P31IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P31IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P32IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P32IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P33IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P33IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P34IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P34IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P35IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P35IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P36IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P36IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P37IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P37IN       : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P30OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P30OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P31OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P31OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P32OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P32OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P33OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P33OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P34OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P34OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P35OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P35OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P36OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P36OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P37OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P37OUT      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P3DAT_REG;

/// P3 Port Enable Register
typedef union P3IOEN_REG_TAG {
    unsigned short  reg;
    struct P3IOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .P30OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P30OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P31OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P31OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P32OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P32OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P33OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P33OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P34OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P34OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P35OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P35OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P36OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P36OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P37OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P37OEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P30IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P30IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P31IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P31IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P32IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P32IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P33IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P33IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P34IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P34IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P35IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P35IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P36IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P36IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P37IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P37IEN      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P3IOEN_REG;

/// P3 Port Pull-up/down Control Register
typedef union P3RCTL_REG_TAG {
    unsigned short  reg;
    struct P3RCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P30REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P30REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P31REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P31REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P32REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P32REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P33REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P33REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P34REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P34REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P35REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P35REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P36REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P36REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P37REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P37REN      : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P30PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P30PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P31PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P31PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P32PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P32PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P33PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P33PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P34PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P34PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P35PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P35PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P36PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P36PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P37PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P37PDPU     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P3RCTL_REG;

/// P3 Port Interrupt Flag Register
typedef union P3INTF_REG_TAG {
    unsigned short  reg;
    struct P3INTF_REG_BIT_TAG {
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P30IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P30IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P31IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P31IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P32IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P32IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P33IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P33IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P34IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P34IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P35IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P35IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P36IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P36IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P37IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P37IF       : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P3INTF_REG;

/// P3 Port Interrupt Control Register
typedef union P3INTCTL_REG_TAG {
    unsigned short  reg;
    struct P3INTCTL_REG_BIT_TAG {
        /**
         * This bit enable port input interrupt.
         * .P30IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P30IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P31IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P31IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P32IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P32IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P33IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P33IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P34IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P34IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P35IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P35IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P36IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P36IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P37IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P37IE       : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P30EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P30EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P31EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P31EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P32EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P32EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P33EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P33EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P34EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P34EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P35EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P35EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P36EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P36EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P37EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P37EDGE     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P3INTCTL_REG;

/// P3 Port Chattering Filter Enable Register
typedef union P3CHATEN_REG_TAG {
    unsigned short  reg;
    struct P3CHATEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the chattering filter function.
         * .P30CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P30CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P31CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P31CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P32CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P32CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P33CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P33CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P34CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P34CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P35CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P35CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P36CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P36CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P37CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P37CHATEN   : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P3CHATEN_REG;

/// P3 Port Mode Select Register
typedef union P3MODSEL_REG_TAG {
    unsigned short  reg;
    struct P3MODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P30SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P30SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P31SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P31SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P32SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P32SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P33SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P33SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P34SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P34SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P35SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P35SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P36SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P36SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P37SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P37SEL      : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P3MODSEL_REG;

/// P3 Port Function Select Register
typedef union P3FNCSEL_REG_TAG {
    unsigned short  reg;
    struct P3FNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P30MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P30MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P31MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P31MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P32MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P32MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P33MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P33MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P34MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P34MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P35MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P35MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P36MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P36MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P37MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P3nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P37MUX      : 2;
    } bit;
    unsigned char   byte_reg[2];
} P3FNCSEL_REG;

/// P4 Port Data Register
typedef union P4DAT_REG_TAG {
    unsigned short  reg;
    struct P4DAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P40IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P40IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P41IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P41IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P42IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P42IN       : 1;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P40OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P40OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P41OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P41OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P42OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P42OUT      : 1;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4DAT_REG;

/// P4 Port Enable Register
typedef union P4IOEN_REG_TAG {
    unsigned short  reg;
    struct P4IOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .P40OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P40OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P41OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P41OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P42OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P42OEN      : 1;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * This bit enable/disable the GPIO port input.
         * .P40IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P40IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P41IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P41IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P42IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P42IEN      : 1;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4IOEN_REG;

/// P4 Port Pull-up/down Control Register
typedef union P4RCTL_REG_TAG {
    unsigned short  reg;
    struct P4RCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P40REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P40REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P41REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P41REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P42REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P42REN      : 1;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P40PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P40PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P41PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P41PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P42PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P42PDPU     : 1;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4RCTL_REG;

/// P4 Port Interrupt Flag Register
typedef union P4INTF_REG_TAG {
    unsigned short  reg;
    struct P4INTF_REG_BIT_TAG {
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P40IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P40IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P41IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P41IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P42IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P42IF       : 1;
        unsigned short      reserved_1  :13;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4INTF_REG;

/// P4 Port Interrupt Control Register
typedef union P4INTCTL_REG_TAG {
    unsigned short  reg;
    struct P4INTCTL_REG_BIT_TAG {
        /**
         * This bit enable port input interrupt.
         * .P40IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P40IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P41IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P41IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P42IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P42IE       : 1;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P40EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P40EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P41EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P41EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P42EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P42EDGE     : 1;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4INTCTL_REG;

/// P4 Port Chattering Filter Enable Register
typedef union P4CHATEN_REG_TAG {
    unsigned short  reg;
    struct P4CHATEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the chattering filter function.
         * .P40CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P40CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P41CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P41CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P42CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P42CHATEN   : 1;
        unsigned short      reserved_1  :13;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4CHATEN_REG;

/// P4 Port Mode Select Register
typedef union P4MODSEL_REG_TAG {
    unsigned short  reg;
    struct P4MODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P40SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P40SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P41SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P41SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P42SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P42SEL      : 1;
        unsigned short      reserved_1  :13;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4MODSEL_REG;

/// P4 Port Function Select Register
typedef union P4FNCSEL_REG_TAG {
    unsigned short  reg;
    struct P4FNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P40MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P4nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P40MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P41MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P4nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P41MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P42MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P4nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P42MUX      : 2;
        unsigned short      reserved_1  :10;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P4FNCSEL_REG;

/// Pd Port Data Register
typedef union PDDAT_REG_TAG {
    unsigned short  reg;
    struct PDDAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .PD0IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      PD0IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .PD1IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      PD1IN       : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * The GPIO port pin status can be read out from this bit.
         * .PD3IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      PD3IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .PD4IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      PD4IN       : 1;
        unsigned short      reserved_2  : 3;    ///< Reserved.
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD0OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD0OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD1OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD1OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD2OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD2OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD3OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD3OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD4OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD4OUT      : 1;
        unsigned short      reserved_3  : 3;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDDAT_REG;

/// Pd Port Enable Register
typedef union PDIOEN_REG_TAG {
    unsigned short  reg;
    struct PDIOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .PD0OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      PD0OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .PD1OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      PD1OEN      : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * This bit enable/disable the GPIO port output.
         * .PD3OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      PD3OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .PD4OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      PD4OEN      : 1;
        unsigned short      reserved_2  : 3;    ///< Reserved.
        /**
         * This bit enable/disable the GPIO port input.
         * .PD0IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      PD0IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .PD1IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      PD1IEN      : 1;
        unsigned short      reserved_3  : 1;    ///< Reserved.
        /**
         * This bit enable/disable the GPIO port input.
         * .PD3IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      PD3IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .PD4IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      PD4IEN      : 1;
        unsigned short      reserved_4  : 3;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDIOEN_REG;

/// Pd Port Pull-up/down Control Register
typedef union PDRCTL_REG_TAG {
    unsigned short  reg;
    struct PDRCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .PD0REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      PD0REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .PD1REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      PD1REN      : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * This bit enable/disable the port pull-up/down control.
         * .PD3REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      PD3REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .PD4REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      PD4REN      : 1;
        unsigned short      reserved_2  : 3;    ///< Reserved.
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .PD0PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      PD0PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .PD1PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      PD1PDPU     : 1;
        unsigned short      reserved_3  : 1;    ///< Reserved.
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .PD3PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      PD3PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .PD4PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      PD4PDPU     : 1;
        unsigned short      reserved_4  : 3;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDRCTL_REG;

/// Pd Port Mode Select Register
typedef union PDMODSEL_REG_TAG {
    unsigned short  reg;
    struct PDMODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD0SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD0SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD1SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD1SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD2SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD2SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD3SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD3SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD4SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD4SEL      : 1;
        unsigned short      reserved_1  :11;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDMODSEL_REG;

/// Pd Port Function Select Register
typedef union PDFNCSEL_REG_TAG {
    unsigned short  reg;
    struct PDFNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD0MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD0MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD1MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD1MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD2MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD2MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD3MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD3MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD4MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD4MUX      : 2;
        unsigned short      reserved_1  : 6;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDFNCSEL_REG;

/// P Port Clock Control Register
typedef union PCLK_REG_TAG {
    unsigned short  reg;
    struct PCLK_REG_BIT_TAG {
        /**
         * These bits select the clock source of PPORT (chattering filter).
         * .CLKSRC[1:0]
         *  These bits select the clock source of PPORT (chattering filter).
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the PPORT operating clock (chattering filter clock).
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * | CLKDIV[3:0  |  0x0   |   0x1  |  0x2   |  0x3   |
         * |             +--------+--------+--------+--------+
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * +-------------+--------+--------+--------+--------+
         * |     0xf     |         1/32,768         | 1/1    |
         * +-------------+--------------------------+        +
         * |     0xe     |         1/16,384         |        |
         * +-------------+--------------------------+        +
         * |     0xd     |          1/8,192         |        |
         * +-------------+--------------------------+        +
         * |     0xc     |          1/4,096         |        |
         * +-------------+--------------------------+        +
         * |     0xb     |          1/2,048         |        |
         * +-------------+--------------------------+        +
         * |     0xa     |          1/1,024         |        |
         * +-------------+--------------------------+        +
         * |     0x9     |           1/512          |        |
         * +-------------+--------------------------+        +
         * |     0x8     |           1/256          |        |
         * +-------------+--------------------------+        +
         * |     0x7     |           1/128          |        |
         * +-------------+--------------------------+        +
         * |     0x6     |           1/64           |        |
         * +-------------+--------------------------+        +
         * |     0x5     |           1/32           |        |
         * +-------------+--------------------------+        +
         * |     0x4     |           1/16           |        |
         * +-------------+--------------------------+        +
         * |     0x3     |           1/8            |        |
         * +-------------+--------------------------+        +
         * |     0x2     |           1/4            |        |
         * +-------------+--------------------------+        +
         * |     0x1     |           1/2            |        |
         * +-------------+--------------------------+        +
         * |     0x0     |           1/1            |        |
         * +-------------+-------------------------+--------+
         */
        unsigned short      CLKSRC      : 2;
        /**
         * These bits configure the key-entry reset function.
         * .KRSTCFG[1:0]
         *  These bits configure the key-entry reset function.
         * +--------------+-------------------------------------+
         * | KRSTCFG[1:0] |           key-entry reset           |
         * +--------------+-------------------------------------+
         * |     0x3      | Reset when P0[3:0] inputs = all low |
         * +--------------+-------------------------------------+
         * |     0x2      | Reset when P0[2:0] inputs = all low |
         * +--------------+-------------------------------------+
         * |     0x1      | Reset when P0[1:0] inputs = all low |
         * +--------------+-------------------------------------+
         * |     0x0      |               Disable               |
         * +--------------+-------------------------------------+
         */
        unsigned short      KRSTCFG     : 2;
        /**
         * These bits select the division ratio of the PPORT operating clock (chattering filter clock).
         * .CLKSRC[1:0]
         *  These bits select the clock source of PPORT (chattering filter).
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the PPORT operating clock (chattering filter clock).
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * | CLKDIV[3:0  |  0x0   |   0x1  |  0x2   |  0x3   |
         * |             +--------+--------+--------+--------+
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * +-------------+--------+--------+--------+--------+
         * |     0xf     |         1/32,768         | 1/1    |
         * +-------------+--------------------------+        +
         * |     0xe     |         1/16,384         |        |
         * +-------------+--------------------------+        +
         * |     0xd     |          1/8,192         |        |
         * +-------------+--------------------------+        +
         * |     0xc     |          1/4,096         |        |
         * +-------------+--------------------------+        +
         * |     0xb     |          1/2,048         |        |
         * +-------------+--------------------------+        +
         * |     0xa     |          1/1,024         |        |
         * +-------------+--------------------------+        +
         * |     0x9     |           1/512          |        |
         * +-------------+--------------------------+        +
         * |     0x8     |           1/256          |        |
         * +-------------+--------------------------+        +
         * |     0x7     |           1/128          |        |
         * +-------------+--------------------------+        +
         * |     0x6     |           1/64           |        |
         * +-------------+--------------------------+        +
         * |     0x5     |           1/32           |        |
         * +-------------+--------------------------+        +
         * |     0x4     |           1/16           |        |
         * +-------------+--------------------------+        +
         * |     0x3     |           1/8            |        |
         * +-------------+--------------------------+        +
         * |     0x2     |           1/4            |        |
         * +-------------+--------------------------+        +
         * |     0x1     |           1/2            |        |
         * +-------------+--------------------------+        +
         * |     0x0     |           1/1            |        |
         * +-------------+-------------------------+--------+
         */
        unsigned short      CLKDIV      : 4;
        /**
         * This bit sets whether the PPORT operating clock is supplied in DEBUG mode or not.
         * .DBRUN
         *  This bit sets whether the PPORT operating clock is supplied in DEBUG mode or not.
         *    1 (R/WP): Clock supplied in DEBUG mode
         *    0 (R/WP): No clock supplied in DEBUG mode
         */
        unsigned short      DBRUN       : 1;
        unsigned short      reserved_1  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PCLK_REG;

/// P Port Interrupt Flag Group Register
typedef union PINTFGRP_REG_TAG {
    unsigned short  reg;
    struct PINTFGRP_REG_BIT_TAG {
        /**
         * This bit indicate that P0 port group includes a port that has generated an interrupt.
         * .P0INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P0INT       : 1;
        /**
         * This bit indicate that P1 port group includes a port that has generated an interrupt.
         * .P1INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P1INT       : 1;
        /**
         * This bit indicate that P2 port group includes a port that has generated an interrupt.
         * .P2INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P2INT       : 1;
        /**
         * This bit indicate that P3 port group includes a port that has generated an interrupt.
         * .P3INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P3INT       : 1;
        /**
         * This bit indicate that P4 port group includes a port that has generated an interrupt.
         * .P4INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P4INT       : 1;
        unsigned short      reserved_1  :11;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PINTFGRP_REG;

#ifdef __cplusplus
}
#endif

#endif // PPORT_REG_H__
