/* Default linker script, for normal executables */
OUTPUT_FORMAT("elf32-c17")
OUTPUT_ARCH(c17)
ENTRY(_start)
SEARCH_DIR(.);
MEMORY
{
	iram	: ORIGIN = 0,		LENGTH = 32K
	irom 	: ORIGIN = 0x8000,	LENGTH = 4064K
}
SECTIONS
{
	.bss (NOLOAD) :
	{
		PROVIDE (__START_bss = .) ;
		*(.bss)
		*(.bss.*)
		*(COMMON)
		PROVIDE (__END_bss = .) ;
	}  > iram
	.vector :
	{
		PROVIDE (__START_vector = .) ;
		KEEP (*crt0.o(.rodata))
		PROVIDE (__END_vector = .) ;
	}  > irom
	.text :
	{
		PROVIDE (__START_text = .) ;
		*(.text.*)
		*(EXCLUDE_FILE (*FlashTimeTable*.o *FlashControlCommon.o *FlashControlWrite.o *FlashControlErase.o) .text)
		PROVIDE (_init_device = DEFINED (_crt0_init_device) ? _crt0_init_device : _crt0_init_dummy ) ;
		PROVIDE (_start_device = DEFINED (_crt0_start_device) ? _crt0_start_device : _crt0_init_dummy ) ;
		PROVIDE (_stop_device = DEFINED (_crt0_stop_device) ? _crt0_stop_device : _crt0_init_dummy ) ;
		PROVIDE (_init_section = DEFINED (_crt0_init_section) ? _crt0_init_section : _crt0_init_dummy ) ;
		PROVIDE (_init_lib = DEFINED (_crt0_init_lib) ? _crt0_init_lib : _crt0_init_dummy ) ;
		PROVIDE (_init_sys = DEFINED (_crt0_init_sys) ? _crt0_init_sys : _crt0_init_dummy ) ;
		PROVIDE (_start1 = DEFINED (_crt0_start1) ? _crt0_start1 : _crt0_init_dummy ) ;
		PROVIDE (_start = DEFINED (_crt0_start0) ? _crt0_start0 : _crt0_init_dummy ) ;
		PROVIDE (_exit = DEFINED (_crt0_exit) ? _crt0_exit : _crt0_init_dummy ) ;
		PROVIDE (__END_text = .) ;
	}  > irom
	.data :
	{
		PROVIDE (__START_data = .) ;
		*(.data)
		*(.data.*)
		PROVIDE (__END_data = .) ;
	}  > iram AT > irom
	
			
	.rodata :
	{
		PROVIDE (__START_rodata = .) ;
		*(EXCLUDE_FILE (*crt0.o *FlashArea.o) .rodata)
		*(.rodata.*)
		PROVIDE (__END_rodata = .) ;
	}  > irom


	PROVIDE (__START_data_lma = LOADADDR(.data));
	PROVIDE (__END_data_lma = LOADADDR(.data) + SIZEOF (.data));
	PROVIDE (__START_stack = 0x0007C0);
	
	.flash_common_text :
	{
		__START_flash_common_text = __END_data ;
		*FlashControlCommon.o(.text);
		*FlashTimeTable*.o(.text);
		__END_flash_common_text = . ; 
	} > iram AT > irom
	
	
	OVERLAY :
	{
		.flash_erase_text 
		{ 
			__START_flash_erase_text = . ;
			*FlashControlErase.o(.text) 
			__END_flash_erase_text = . ;
		}
		.flash_write_text 
		{ 
			__START_flash_write_text = . ;
			*FlashControlWrite.o(.text) 
			__END_flash_write_text = . ;
		}
	
	} > iram AT > irom
	
	
	.flashdata_address 0x00F800 : 
	{
	   __START_flashdata_address = . ;
	   *FlashArea.o(.rodata)
	   __END_flashdata_address = . ; 
	 }
	 
	
	__START_flash_common_text_lma = LOADADDR(.flash_common_text);
	__START_flash_erase_text_lma = __load_start_flash_erase_text;
	__START_flash_write_text_lma = __load_start_flash_write_text;	 

	

	
}
